# Changes

## 0.1.7

* Remove debug code

## 0.1.6

* Fixed parsing of num_mapped and num_unmapped 
* Add `empty` property to `Offset`

## 0.1.5

* Add iter_intervals method to BaiIndex

## 0.1.4

* Add CLI

## 0.1.3

* Bugfix

## 0.1.2

* Add conveneince method for resolving and parsing the index file

## 0.1.0

* Initial checkin